# ritm_annotation

[![codecov](https://codecov.io/gh/lucasew/ritm_annotation/branch/main/graph/badge.svg?token=ritm_annotation_token_here)](https://codecov.io/gh/lucasew/ritm_annotation)
[![CI](https://github.com/lucasew/ritm_annotation/actions/workflows/main.yml/badge.svg)](https://github.com/lucasew/ritm_annotation/actions/workflows/main.yml)

Tool to do dataset annotation for semantic segmentation datasets.

Based on [SamsungLabs/ritm_interactive_segmentation](https://github.com/SamsungLabs/ritm_interactive_segmentation)

**Work in progress**

## Install it from PyPI

```bash
pip install ritm_annotation # not yet
```

## Usage

```py
from ritm_annotation import BaseClass # TODO: make this part
from ritm_annotation import base_function

BaseClass().base_method()
base_function()
```

```bash
$ python -m ritm_annotation
#or
$ ritm_annotation
```

## Development

Read the [CONTRIBUTING.md](CONTRIBUTING.md) file.
